@@ -30,7 +30,7 @@
 
 typedef struct _dcmap dcmap_t;
 
-F_NONNULL F_MALLOC
+F_NONNULL F_WUNUSED
 dcmap_t* dcmap_new(vscf_data_t* map_cfg, dclists_t* dclists, const unsigned parent_def, const unsigned true_depth, const char* map_name, const bool allow_auto);
 
 F_NONNULL F_PURE
